@@ -156,7 +156,7 @@ class Welcome:
 #/_/    \____/_/ |_/\____/ 
 #
     @staticmethod
-    def get_fetchdata(elapsed=timeUtils.elapsedtime(),format='json',  version='beta'):
+    def get_fetchdata(elapsed=timeUtils.elapsedtime(),format='json',  version='.204'):
         d = dict()
         d['Software']='Aniachi Technologies.'
         s = getpass.getuser()+'@'+platform.node()
@@ -169,7 +169,7 @@ class Welcome:
         d['Architecture']=platform.processor()
         s = platform.machine()+'  '+platform.system()+' Kernel version '+platform.release()
         d['Kernel']=s
-        d['CPU Info']=cpuinfo.get_cpu_info()['brand']
+        d['CPU Info']=cpuinfo.get_cpu_info()['brand_raw']
         d['Screen resolution']=Welcome.screen_resolution()
         d['Python Version']=platform.python_version()
         d['Processors']=psutil.cpu_count(logical=False)
@@ -193,7 +193,7 @@ class Welcome:
         d['Current date']=str(datetime.datetime.now())
         d['Elapsed time:']=elapsed.getElapsedTime()
 
-        print(d)
+
 
         if format == 'json':
             return json.dumps(d)
